pub struct BitVectorBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl BitVectorBuilder
impl BitVectorBuilder
Sourcepub fn with_capacity(bits: usize) -> Self
pub fn with_capacity(bits: usize) -> Self
Creates a builder with capacity for at least bits bits.
Sourcepub fn filled(len: usize, value: bool) -> Self
pub fn filled(len: usize, value: bool) -> Self
Creates a builder with all bits set to value, length len.
Sourcepub fn get(&self, index: usize) -> Option<bool>
pub fn get(&self, index: usize) -> Option<bool>
Gets the bit at the given index (read access during build).