pub enum ProjectExpr {
Column(usize),
Constant(Value),
PropertyAccess {
column: usize,
property: String,
},
EdgeType {
column: usize,
},
Expression {
expr: FilterExpression,
variable_columns: HashMap<String, usize>,
},
NodeResolve {
column: usize,
},
EdgeResolve {
column: usize,
},
}Expand description
A projection expression.
Variants
Column(usize)
Reference to an input column.
Constant(Value)
A constant value.
PropertyAccess
Property access on a node/edge column.
Fields
EdgeType
Edge type accessor (for type(r) function).
Expression
Full expression evaluation (for CASE WHEN, etc.).
Fields

expr: FilterExpressionThe filter expression to evaluate.
NodeResolve
Resolve a node ID column to a full node map with metadata and properties.
EdgeResolve
Resolve an edge ID column to a full edge map with metadata and properties.