Module single_row

Module single_row 

Single row, empty, and node list operators.

  • SingleRowOperator: Produces exactly one empty row. Used for queries like UNWIND [1,2,3] AS x RETURN x that don’t have a MATCH clause.
  • EmptyOperator: Produces no rows. Used when zone map pre-filtering determines that a filter predicate cannot match any data.
  • NodeListOperator: Produces rows from a pre-computed list of node IDs. Used when property index lookups return a specific set of matching nodes.

Structs

EmptyOperator
An operator that produces no rows.
NodeListOperator
An operator that produces rows from a pre-computed list of node IDs.
SingleRowOperator
An operator that produces exactly one empty row.