pub struct DistinctOperator { /* private fields */ }Expand description
Distinct operator.
Removes duplicate rows from the input. Can operate on all columns or a subset.
Implementations
Sourceimpl DistinctOperator
impl DistinctOperator
Sourcepub fn new(child: Box<dyn Operator>, output_schema: Vec<LogicalType>) -> Self
pub fn new(child: Box<dyn Operator>, output_schema: Vec<LogicalType>) -> Self
Creates a new distinct operator that considers all columns.
Sourcepub fn into_parts(self) -> (Box<dyn Operator>, Option<Vec<usize>>)
pub fn into_parts(self) -> (Box<dyn Operator>, Option<Vec<usize>>)
Decomposes this operator for push-based conversion.
Sourcepub fn on_columns(
child: Box<dyn Operator>,
columns: Vec<usize>,
output_schema: Vec<LogicalType>,
) -> Self
pub fn on_columns( child: Box<dyn Operator>, columns: Vec<usize>, output_schema: Vec<LogicalType>, ) -> Self
Creates a distinct operator that considers only specified columns.