pub struct ProjectOperator { /* private fields */ }Expand description
A project operator that selects and transforms columns.
Implementations
Sourceimpl ProjectOperator
impl ProjectOperator
Sourcepub fn new(
child: Box<dyn Operator>,
projections: Vec<ProjectExpr>,
output_types: Vec<LogicalType>,
) -> Self
pub fn new( child: Box<dyn Operator>, projections: Vec<ProjectExpr>, output_types: Vec<LogicalType>, ) -> Self
Creates a new project operator.
Panics
Panics if projections and output_types have different lengths.
Sourcepub fn with_store(
child: Box<dyn Operator>,
projections: Vec<ProjectExpr>,
output_types: Vec<LogicalType>,
store: Arc<dyn GraphStoreSearch>,
) -> Self
pub fn with_store( child: Box<dyn Operator>, projections: Vec<ProjectExpr>, output_types: Vec<LogicalType>, store: Arc<dyn GraphStoreSearch>, ) -> Self
Creates a new project operator with store access for property lookups.
Panics
Panics if projections and output_types have different lengths.
Sourcepub fn with_transaction_context(
self,
epoch: EpochId,
transaction_id: Option<TransactionId>,
) -> Self
pub fn with_transaction_context( self, epoch: EpochId, transaction_id: Option<TransactionId>, ) -> Self
Sets the transaction context for MVCC-aware property lookups.
Sourcepub fn with_session_context(self, context: SessionContext) -> Self
pub fn with_session_context(self, context: SessionContext) -> Self
Sets the session context for introspection functions.
Sourcepub fn into_parts(
self,
) -> (Box<dyn Operator>, Vec<ProjectExpr>, Vec<LogicalType>)
pub fn into_parts( self, ) -> (Box<dyn Operator>, Vec<ProjectExpr>, Vec<LogicalType>)
Decomposes this operator into its child and projections for push-based conversion.
Sourcepub fn select_columns(
child: Box<dyn Operator>,
columns: Vec<usize>,
types: Vec<LogicalType>,
) -> Self
pub fn select_columns( child: Box<dyn Operator>, columns: Vec<usize>, types: Vec<LogicalType>, ) -> Self
Creates a project operator that selects specific columns.