Module value_utils

Module value_utils 

Shared value comparison and conversion utilities.

Used by pull-based and push-based aggregate, filter, and sort operators to avoid duplicating comparison logic across six different files.

Functions

compare_values
Compares two values with partial ordering (returns None for incomparable types).
compare_values_total
Compares two values with total ordering (returns Equal for incomparable types).
is_greater_than
Returns true if new is greater than current (for MAX aggregation).
is_less_than
Returns true if new is less than current (for MIN aggregation).
value_to_f64
Converts a value to f64 for numeric aggregations.