pub trait Mergeable: Send + Default {
// Required method
fn merge(&mut self, other: Self);
}Expand description
Trait for types that can be merged in parallel fold-reduce operations.
Implement this for custom accumulator types that need to be combined after parallel processing.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.